# [1.8.5](https://github.com/seriaati/ambr/compare/v1.8.4..v1.8.5) - 2025-05-02

## Bug Fixes

- Handle int val in Quote.tips - ([84ac65a](https://github.com/seriaati/ambr/commit/84ac65a43cb88051364c3a8275714a55070642b8))

## Continuous Integrations

- Remove biweek release - ([c0a20f0](https://github.com/seriaati/ambr/commit/c0a20f093318e32c223d14a42437f34295dc790d))

## Documentation

- Update mkdocs config - ([87a0862](https://github.com/seriaati/ambr/commit/87a0862867de2178fbf8695c38971d0fe89c45bc))

## Miscellaneous Chores

- **(deps)** lock file maintenance ([#96](https://github.com/seriaati/ambr/issues/96)) - ([6b7c84b](https://github.com/seriaati/ambr/commit/6b7c84bf1e19d8b6825c44cec00b3143a6b89a27))
- **(deps)** update astral-sh/setup-uv action to v6 ([#97](https://github.com/seriaati/ambr/issues/97)) - ([7afdd24](https://github.com/seriaati/ambr/commit/7afdd24f4afe022142aad3b5e83505639dde50ca))
- **(deps)** lock file maintenance ([#98](https://github.com/seriaati/ambr/issues/98)) - ([0572b88](https://github.com/seriaati/ambr/commit/0572b882e0764d263f908f7665ab79560b34c153))
- Add docs URL to project.urls - ([7925af3](https://github.com/seriaati/ambr/commit/7925af3d41258c5789f277378f26fc3bc1074eb1))

